Opens the default web browser with a display of two continuous distributions
shown side-by-side and reflected to suggest a closed container.
Interactive options control the display of water levels and the choice of
the shapes of the underlying distributions.
Usage
side_by_side_slider(name, dists = make_df_list())
Arguments
name
Name of distribution to contrast with normal
dists
Named list of (d=density, q=quantile, r=sample) distributions (see make_df_list())